@@ -178,7 +178,6 @@ set_localaddrs(struct smtpd *conf, struct table *localnames)
 	struct sockaddr_in	*sain;
 	struct sockaddr_in6	*sin6;
 	struct table		*t;
-	char buf[NI_MAXHOST + 5];
 
 	t = table_create(conf, "static", "<anyhost>", NULL);
 	table_add(t, "local", NULL);
@@ -203,8 +202,6 @@ set_localaddrs(struct smtpd *conf, struct table *localnames)
 #endif
 			table_add(t, ss_to_text(&ss), NULL);
 			table_add(localnames, ss_to_text(&ss), NULL);
-			(void)snprintf(buf, sizeof buf, "[%s]", ss_to_text(&ss));
-			table_add(localnames, buf, NULL);
 			break;
 
 		case AF_INET6:
@@ -230,10 +227,6 @@ set_localaddrs(struct smtpd *conf, struct table *localnames)
 #endif
 			table_add(t, ss_to_text(&ss), NULL);
 			table_add(localnames, ss_to_text(&ss), NULL);
-			(void)snprintf(buf, sizeof buf, "[%s]", ss_to_text(&ss));
-			table_add(localnames, buf, NULL);
-			(void)snprintf(buf, sizeof buf, "[ipv6:%s]", ss_to_text(&ss));
-			table_add(localnames, buf, NULL);
 			break;
 		}
 	}
