@@ -456,7 +456,8 @@ ascii_load_field(const char *field, struct envelope *ep, char *buf)
 		return ascii_load_uint8(&ep->dsn_notify, buf);
 
 	if (strcasecmp("dsn-orcpt", field) == 0)
-		return ascii_load_mailaddr(&ep->dsn_orcpt, buf);
+		return ascii_load_string(ep->dsn_orcpt, buf,
+		    sizeof(ep->dsn_orcpt));
 
 	if (strcasecmp("dsn-ret", field) == 0)
 		return ascii_load_dsn_ret(&ep->dsn_ret, buf);
@@ -716,11 +717,8 @@ ascii_dump_field(const char *field, const struct envelope *ep,
 	if (strcasecmp(field, "dsn-ret") == 0)
 		return ascii_dump_dsn_ret(ep->dsn_ret, buf, len);
 
-	if (strcasecmp(field, "dsn-orcpt") == 0) {
-		if (ep->dsn_orcpt.user[0] && ep->dsn_orcpt.domain[0])
-			return ascii_dump_mailaddr(&ep->dsn_orcpt, buf, len);
-		return 1;
-	}
+	if (strcasecmp(field, "dsn-orcpt") == 0)
+		return ascii_dump_string(ep->dsn_orcpt, buf, len);
 
 	if (strcasecmp(field, "dsn-envid") == 0)
 		return ascii_dump_string(ep->dsn_envid, buf, len);
